@@ -1,11 +1,12 @@
 package Pod::Weaver;
-our $VERSION = '3.100680';
+our $VERSION = '3.100710';
 use Moose;
 # ABSTRACT: weave together a Pod document from an outline
 
 use namespace::autoclean;
 
 
+use Log::Dispatchouli 1.100710; # proxy
 use Moose::Autobox 0.10;
 use Pod::Elemental;
 use Pod::Elemental::Document;
@@ -14,28 +15,16 @@ use Pod::Weaver::Role::Plugin;
 use String::Flogger;
 
 
-{
-  package
-    Pod::Weaver::_Logger;
-our $VERSION = '3.100680';
-  sub log {
-    shift;
-    shift if ref $_[0] eq 'HASH';
-    printf "%s\n", join q{ }, map {; String::Flogger->flog($_) } @_;
-  }
-  sub log_fatal {
-    shift;
-    shift if ref $_[0] eq 'HASH';
-    die sprintf "%s\n", join q{ }, map {; String::Flogger->flog($_) } @_;
-  }
-  sub log_debug { }
-  sub new { bless {} => $_[0] }
-}
-
 has logger => (
   is      => 'ro',
   lazy    => 1,
-  default => sub { Pod::Weaver::_Logger->new },
+  default => sub {
+    Log::Dispatchouli->new({
+      ident     => 'Pod::Weaver',
+      to_stdout => 1,
+      log_pid   => 0,
+    });
+  },
   handles => [ qw(log log_fatal log_debug) ]
 );
 
@@ -172,7 +161,7 @@ Pod::Weaver - weave together a Pod document from an outline
 
 =head1 VERSION
 
-version 3.100680
+version 3.100710
 
 =head1 SYNOPSIS
 
